@@ -1,9 +1,9 @@
 try:
     from normatrix.source.file_parser import CFileParse
-    from normatrix.source.file_parser import TypeLine
+    from normatrix.source.config import TypeLine
 except ModuleNotFoundError:
     from normatrix.normatrix.source.file_parser import CFileParse
-    from normatrix.normatrix.source.file_parser import TypeLine
+    from normatrix.normatrix.source.config import TypeLine
 
 import re
 
