@@ -69,10 +69,10 @@ REG_TYPELINE = {
     TypeLine.GLOBAL: [
         re.compile("^(static ){0,1}(const ){0,1}\w{1,} \*{0,}\w{1,}(\[[0-9]{0,}\]){0,1} = ((\w{0,})|({\n{0,1} {0,}\w{0,}(,\n{0,1} {0,}\w{0,}){0,})|)\n{0,1}}{0,1};")
     ],
-    TypeLine.FUNC_PROTO: [
-        re.compile("^((\w{1,}?(\*{0,}?) ){1,}?(\*){0,}?\w{1,}?)\(((void)|((\w{1,}? {0,}?){1,}?(\*){0,}? (\*){0,}?\w{1,}?(\[\d{0,}?\]){0,}?(, {0,}?(\n {0,}){0,1}?){0,}?){1,4}?)\);")
-    ],
     TypeLine.FUNCTION: [
-        re.compile("^((\w{1,}?(\*{0,}?) ){1,}?(\*){0,}?\w{1,}?)\(((void)|((\w{1,}? {0,}?){1,}?(\*){0,}? (\*){0,}?\w{1,}?(\[\d{0,}?\]){0,}?(, {0,}?(\n {0,}){0,1}?){0,}?){1,4}?)\)\n\{((.*)\n){1,}?\}")
+        re.compile("((static )|(const )){0,}\w{1,}(\*){0,} (\*){0,}\w{1,}\(((void)|(\n{0,1}.*( *\w{1,}){1,}(\*){0,} (\*){0,}\w{1,}(\[[0-9]{0,}\]){0,}(, {0,1}\n{0,1}( *\w{1,})(\*){0,} (\*){0,}\w{1,}(\[\d{0,}\]){0,}){0,3})\n{0,1} {0,})\)\n{0,1} {0,1}{\n(.*\n)*?}")
+    ],
+    TypeLine.FUNC_PROTO: [
+        re.compile("((static )|(const )){0,}\w{1,}(\*){0,} (\*){0,}\w{1,}\(((void)|(\n{0,1}.*( *\w{1,}){1,}(\*){0,} (\*){0,}\w{1,}(\[[0-9]{0,}\]){0,}(, {0,1}\n{0,1}( *\w{1,})(\*){0,} (\*){0,}\w{1,}(\[\d{0,}\]){0,}){0,3})\n{0,1} {0,})\);")
     ]
 }
